@@ -1,5 +1,5 @@
 
-# $Id: BySellerID.pm,v 2.5 2008/02/24 21:16:21 Daddy Exp $
+# $Id: BySellerID.pm,v 2.7 2009/05/02 13:28:09 Martin Exp $
 
 =head1 NAME
 
@@ -45,6 +45,10 @@ Please tell the author if you find any!
 C<WWW::Search::Ebay::BySellerID> was written by and is maintained by
 Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
 
+=head1 LICENSE
+
+Copyright (C) 1998-2009 Martin 'Kingpin' Thurn
+
 =cut
 
 package WWW::Search::Ebay::BySellerID;
@@ -54,9 +58,9 @@ use warnings;
 
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.5 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.7 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
-sub native_setup_search
+sub _native_setup_search
   {
   my ($self, $sQuery, $rh) = @_;
   $rh->{'MfcISAPICommand'} = 'MemberSearchResult';
@@ -78,8 +82,8 @@ sub native_setup_search
   $rh->{'catref'} = 'C5';
   $rh->{'from'} = 'R7';
   $rh->{'pfid'} = '0';
-  return $self->SUPER::native_setup_search('', $rh);
-  } # native_setup_search
+  return $self->SUPER::_native_setup_search('', $rh);
+  } # _native_setup_search
 
 1;
 
